********
Frontend
********

Pagination
==========

The blog index page comes with pagination support. You can set the
number of posts per page using the `POST_LIST_PAGINATION` setting.

If there are more then 3 pages, there will be a "..." in the pagination.
If there are more then 10 pages, there will be two "..." in the pagination.
